import { SchemaFromBackend } from '@graphpolaris/shared/data-access/store';
import { MultiGraph } from 'graphology';
import { parse } from 'path/posix';
import { parseSchemaFromBackend } from '..';
import * as simpleSchema from './mockdata/simple.json';
import * as moviewSchema from './mockdata/moviesSchema.json';
import * as northwindSchema from './mockdata/northwindSchema.json';
import * as twitterSchema from './mockdata/twitterSchema.json';
import { Attributes } from 'graphology-types';

describe('SchemaUsecases', () => {
  test.each([
    { data: simpleSchema },
    { data: moviewSchema },
    { data: northwindSchema },
    { data: twitterSchema },
  ])('parseSchemaFromBackend parsing should work', ({ data }) => {
    // console.log('testinput', input);

    const parsed = parseSchemaFromBackend(data as SchemaFromBackend);
    expect(parsed).toBeDefined();

    let parsedNodeAttributes: Attributes[] = []; 
    parsed.forEachNode((node, attr) => {
      // console.log('Node', node, attr);
      parsedNodeAttributes.push(attr.attributes);
    });

    let parsedEdgeAttributes: Attributes = [];
    parsed.forEachEdge((edge, attr, source, target, sa, ta, undirected) => {
      // console.log('Edge', edge, attr, source, target, sa, ta, undirected);
      parsedEdgeAttributes.push(attr.attribute);
    });

    expect(data.nodes.length).toEqual(parsed.order);
    expect(data.edges.length).toEqual(parsed.size);

    let inputNodeAttributes: Attributes = [];
    data.nodes.forEach((node) => {
      inputNodeAttributes.push(node.attributes as Attributes);
    });

    let inputEdgeAttributes: Attributes = [];
    data.edges.forEach((edge) => {
      inputEdgeAttributes.push(edge.attributes as Attributes);
    });

    expect(inputNodeAttributes).toEqual(parsedNodeAttributes);
    expect(inputEdgeAttributes).toEqual(parsedEdgeAttributes);
  });

  it('should export and reimport', () => {
    const parsed = parseSchemaFromBackend(simpleSchema as SchemaFromBackend);
    const reload = MultiGraph.from(parsed.export());

    expect(parsed).toStrictEqual(reload);
  });

  test.each([
    //     import * as simpleSchema from './mockdata/simple.json';
    // import * as moviewSchema from './mockdata/moviesSchema.json';
    // import * as northwindSchema from './mockdata/northwindSchema.json';
    // import * as twitterSchema from './mockdata/twitterSchema.json';
    { data: simpleSchema },
    { data: moviewSchema },
    { data: northwindSchema },
    { data: twitterSchema },
  ])('should load my test json $data', ({ data }) => {
    expect(data).toBeDefined();
    expect(data.nodes).toBeDefined();
  });
});
